<template>
<div class="col-sm-12">
    <div class="card-body btn-showcase">
        <div class="modal fade bd-example-modal-lg" id="addContactModal" ref="addContactModal" tabindex="-1" role="dialog" aria-labelledby="exampleModalLabel" aria-hidden="true">
            <div class="modal-dialog modal-xl" role="document">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title" id="exampleModalLabel2">Add Contact</h5>
                        <button class="btn-close" type="button" data-bs-dismiss="modal" aria-label="Close" v-on:click="hideModal"></button>
                    </div>
                    <div class="card-body">
                        <section class="" style="background-color: #d5e2e9">
                            <div class="container-xl py-4">
                                <div class="row text-center mb-7">
                                    <div class="col-md-12">
                                        <!-- <h4 class="h-5 font-weight-regular mb-2">GROW TRAFFIC &amp; INCREASE REVENUE </h4> -->
                                        <h2 class="mb-4 display-6 text-center fw-bold">Tell us about your project</h2>
                                        <p class="standart-size">Let us help you get your business online and grow it with passion
                                        </p>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-8 offset-md-2">
                                        <form v-on:submit.prevent="createContact">
                                            <div class="row">
                                                <div class="col-md-12">
                                                    <div class="form-group">
                                                        <label for="website-url">Website URL</label>
                                                        <input type="text" name="url" v-model="contact.url" class="form-control custom-width-100" id="website-url" placeholder="www.evaaj.com">
                                                    </div>
                                                </div>
                                                <div class="col-md-6">
                                                    <div class="form-group">
                                                        <label for="name">Name<sup class="text-danger">*</sup></label>
                                                        <input type="text" name="name" v-model="contact.name" class="form-control custom-width-100" id="name" placeholder="Cooper Kirk">
                                                        <small v-if="errors.name" class="text-danger">{{ errors.name }}</small>
                                                    </div>
                                                </div>
                                                <div class="col-md-6">
                                                    <div class="form-group">
                                                        <label for="email">Email<sup class="text-danger">*</sup></label>
                                                        <input type="email" name="email" v-model="contact.email" class="form-control custom-width-100" id="email" placeholder="gomy@mailinator.com">
                                                        <small v-if="errors.email" class="text-danger">{{ errors.email }}</small>
                                                    </div>
                                                </div>
                                                <div class="col-md-6">
                                                    <div class="form-group">
                                                        <label for="phone">Phone</label>
                                                        <input type="tel" name="phone" v-model="contact.phone" class="form-control custom-width-100" id="phone" placeholder="(773)266-8835">
                                                        <small id="phoneHelpInline" class="text-muted">(optional)</small>
                                                    </div>
                                                </div>
                                                <div class="col-md-6">
                                                    <div class="form-group">
                                                        <label for="company">Company</label>
                                                        <input type="text" name="company" v-model="contact.company" class="form-control custom-width-100" id="company" placeholder="Hunter and Campos Trading">
                                                        <small id="companyHelpInline" class="text-muted">(optional)</small>
                                                    </div>
                                                </div>
                                                <div class="col-md-6">
                                                    <div class="form-group">
                                                        <label for="city">City</label>
                                                        <input type="text" name="city" v-model="contact.city" class="form-control custom-width-100" id="city" placeholder="Cooper Kirk">
                                                    </div>
                                                </div>
                                                <div class="col-md-6">
                                                    <div class="form-group">
                                                        <label for="country">Country</label>
                                                        <input type="text" name="country" v-model="contact.country" class="form-control custom-width-100" id="country" placeholder="Hunter and Campos Trading">
                                                        <small id="countryHelpInline" class="text-muted">(optional)</small>
                                                    </div>
                                                </div>
                                                <div class="col-md-12">
                                                    <div class="form-group">
                                                        <label for="message">Details</label>
                                                        <textarea class="form-control custom-width-100 height-200" name="description" v-model="contact.description" id="message" placeholder="Your Message"></textarea>
                                                        <small id="messageHelpInline" class="text-muted">Please, let us know the best time to contact you by phone (if provided).</small>
                                                    </div>
                                                </div>
                                                <div class="col-md-6">
                                                    <button class="btn btn-md btn-orange mt-3" id="submit" type="submit">Hear from an expert</button>
                                                </div>
                                            </div>
                                        </form>
                                    </div>
                                </div>
                            </div>
                        </section>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
</template>

<script>
import {
    reactive,
    ref,
    toRefs,
    inject
} from 'vue';

import {
    useStore
} from 'vuex';
import {
    Modal
} from 'bootstrap';
import axios from 'axios'

export default {
    // name: "ContactAdd",
    setup(props, ctx) {
        const store = useStore();
        const toast = inject('toast');
        const state = reactive({
            contact: {
                url: '',
                name: '',
                email: '',
                phone: '',
                company: '',
                description: '',
                city: '',
                country: '',
            },
            errors: {},
            successMessage: '',
        });
        let modal = {
            type: Object,
            default: {}
        };
        async function createContact() {
            try {
                state.errors = {};
                store.state.isLoading = true;

                const response = await axios.post('/contact', state.contact); // Await the Axios request

                // Clear the form fields
                for (const key in state.contact) {
                    if (Object.prototype.hasOwnProperty.call(state.contact, key)) {
                        state.contact[key] = '';
                    }
                }

                state.successMessage = response.data.message;
                modal.hide(); // Assuming 'modal' is correctly defined
                toast.success({
                    title: 'Success!',
                    message: response.data.message,
                    delay: 5000
                });

                store.state.isLoading = false;
            } catch (error) {
                console.log(error);
                store.state.isLoading = false;

                if (error.response && error.response.status === 422) {
                    state.errors = error.response.data.errors;
                    toast.error({
                        title: 'Error!',
                        message: error.response.data.message,
                        delay: 5000
                    });
                } else {
                    toast.error({
                        title: 'Error!',
                        message: 'Some error occurred, Please try again!',
                        delay: 5000
                    });
                }
            }
        }
        const addContactModal = ref(null);

        function showModal() {
            modal = new Modal(addContactModal.value);
            modal.show();
        }

        function hideModal() {
            modal.hide();
        }
        return {
            ...toRefs(state),
            addContactModal,
            showModal,
            hideModal,
            createContact
        }
    }
}
</script>

<style scoped>
/* @import url('../../../css/website/custom.min.css'); */
</style>
